/*********************************************************************************
 * Distribution include file for ORLED 9014 RL28 serial communication clients.
 *********************************************************************************/

// Command opcodes.
#define CMD_END			0x00	// Command message terminator -- not a valid command opcode.
#define	CMD_QUERY		0x01	// Request status.
#define	CMD_CONTROL		0x02	// Program ringlight state.
#define CMD_ASYNC		0x03	// Enable/disable asynchronous notification messages (e.g., kbd, fault).

// Classification of received notification message.
typedef enum MCLASS {
	MCLASS_NONE			= 0,	// No message (timeout, if wait asserted).
	MCLASS_SYNC			= 1,	// Synchronous message (command ack/nak).
	MCLASS_ASYNC		= 2,	// Asyncronous message (keypress, etc.).
	MCLASS_INVALID		= 3		// Unknown message type.
} MCLASS;

// Type of received notification message.
typedef enum MTYPE {
	MTYPE_INVALID		= 0,	// Invalid message type. This is never present (nor possible) in a message.
	MTYPE_KEYUP			= 1,	// IntensityUp keypress
	MTYPE_KEYDOWN		= 2,	// IntensityDown keypress
	MTYPE_KEYPOWER		= 3,	// Power keypress
	MTYPE_KEYQUAD0		= 4,	// Quadrant 0 keypress
	MTYPE_KEYQUAD1		= 5,	// Quadrant 1 keypress
	MTYPE_KEYQUAD2		= 6,	// Quadrant 2 keypress
	MTYPE_KEYQUAD3		= 7,	// Quadrant 3 keypress
	MTYPE_CMDACK		= 8,	// Serial command ACK
	MTYPE_CMDNAK		= 9,	// Serial command NAK (unrecognized command)
	MTYPE_FAULT			= 10	// Cable fault status change
} MTYPE;

// Notification message.
typedef struct NMSG {
	char	buf[3];				// Raw message buffer.
								// Parsed ringlight status (populated for most message types):
	MTYPE	messageType;		//   Message type code.
	int		powerEnable;		//   Boolean power enable: 1=on, 0=off.
	int		quadEnable[4];		//   Boolean quadrant enables (bits 3..0): 1=on, 0=off.
	int		intensity;			//   Light intensity: 0 (dim) to 7 (bright).
	int		powerFault;			//   Boolean power (cable) fault status: 1=fault, 0=normal.
	int		keyboardFault;		//   Boolean keyboard fault status: 1=fault, 0=normal.
} NMSG;

// Functions in os9014.c
int ComportOpen(char *comport);
void ComportClose(void);
int ComportSend(char *buf, int nbytes);
int ComportRecv(char *c);

// Functions in api9014.c
MCLASS RinglightRecvMessage(NMSG *msg, int wait);
void RinglightSendCommand(char opcode, char data);
