///////////////////////////////////////////////////////////////////////////////////////
// File     : os9014.c
// Function : Low level functions for ORLED Model 9014 controller with RL-28 ringlight
// Target   : Windows
///////////////////////////////////////////////////////////////////////////////////////


#include <windows.h>
#include <conio.h>
#include <stdio.h>

#include "include9014.h"


// Storage -------------

static HANDLE		hSerial			= INVALID_HANDLE_VALUE;
static DCB			dcbSerialParams	= {0};
static COMMTIMEOUTS timeouts		= {0};


///////////////////////////////////////////////
// Open serial communication port.

int ComportOpen(char *comport)
{
	hSerial = CreateFile(comport, GENERIC_READ | GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
	
	if (hSerial==INVALID_HANDLE_VALUE)
	{
		char errmsg[200];

		FormatMessage( 
			FORMAT_MESSAGE_FROM_SYSTEM,
			NULL,
			GetLastError(),
			MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
			errmsg,
			sizeof(errmsg),
			NULL 
		);

		printf ("CreateFile failed: %s\n", errmsg);

		return 1;		//error
	}
	
	dcbSerialParams.DCBlength=sizeof(dcbSerialParams);
	if (!GetCommState(hSerial, &dcbSerialParams))
		return 2;		//error

	dcbSerialParams.BaudRate	= CBR_1200;
	dcbSerialParams.ByteSize	= 8;
	dcbSerialParams.StopBits	= ONESTOPBIT;
	dcbSerialParams.Parity		= NOPARITY;
	if (!SetCommState(hSerial, &dcbSerialParams))
		return 3;		//error
	
	timeouts.ReadIntervalTimeout			= MAXDWORD;
	timeouts.ReadTotalTimeoutConstant		= 0;
	timeouts.ReadTotalTimeoutMultiplier		= 0;
	timeouts.WriteTotalTimeoutConstant		= 0;
	timeouts.WriteTotalTimeoutMultiplier	= 0;
	if (!SetCommTimeouts(hSerial, &timeouts))
		return 4;		//error

	return 0;	// ok
}

////////////////////////////////////////////////////
// Close serial communication port.

void ComportClose(void)
{
	if (hSerial!=INVALID_HANDLE_VALUE)
		CloseHandle(hSerial);
}

///////////////////////////////////////////////////////////
// Send binary chars to the ringlight controller.

int ComportSend(char *buf, int nbytes)
{
	int nBytesWritten;
	WriteFile( hSerial, buf, nbytes, &nBytesWritten, NULL );
	return nBytesWritten;
}

///////////////////////////////////////////////////////////
// Receive comport byte. Return true if byte received.

int ComportRecv(char *c)
{
	DWORD dwBytesRead = 0;

	if ( ReadFile(hSerial, c, 1, &dwBytesRead, NULL) )		// Fetch received char if one is pending.
		return dwBytesRead;		// no errors; return 1 if char received, else 0

	return 0;	// error
}
